@@ -103,9 +103,7 @@ async def _set_logger_labels(
         code = await res.code()
         assert str(code) == "StatusCode.OK", str(code)
     except BaseException:
-        # NOTE hiding this for now to not print on every request
-        # logger.debug("Failed to set logger labels", exc_info=True)
-        pass
+        logger.debug("Failed to set logger labels", exc_info=True)
 
 
 def wrap_app(cls: type[App], **kwargs) -> IsolatedFunction:
