@@ -7,11 +7,6 @@ from structlog.typing import EventDict, WrappedLogger
 
 from .style import LEVEL_STYLES
 
-# Unfortunately structlog console processor does not support
-# more general theming as a public API. Consider a PR on the
-# structlog repo to add better support for it.
-structlog.dev._ColorfulStyles.bright = ""
-
 
 class DebugConsoleLogProcessor:
     """
