@@ -1,7 +1,8 @@
 from __future__ import annotations
 
-from fal.toolkit.file import CompressedFile, File
-from fal.toolkit.image.image import Image, ImageSizeInput, get_image_size
+from fal.toolkit.audio.audio import Audio, AudioField
+from fal.toolkit.file import CompressedFile, File, FileField
+from fal.toolkit.image.image import Image, ImageField, ImageSizeInput, get_image_size
 from fal.toolkit.optimize import optimize
 from fal.toolkit.utils import (
     FAL_MODEL_WEIGHTS_DIR,
@@ -11,14 +12,21 @@ from fal.toolkit.utils import (
     download_file,
     download_model_weights,
 )
+from fal.toolkit.video.video import Video, VideoField
 
 __all__ = [
+    "Audio",
+    "AudioField",
     "CompressedFile",
     "File",
+    "FileField",
     "Image",
+    "ImageField",
     "ImageSizeInput",
     "get_image_size",
     "optimize",
+    "Video",
+    "VideoField",
     "FAL_MODEL_WEIGHTS_DIR",
     "FAL_PERSISTENT_DIR",
     "FAL_REPOSITORY_DIR",
