@@ -84,15 +84,15 @@ def _try_with_fallback(
     fallback_save_kwargs: dict,
 ) -> Any:
     if fallback_repository is None:
-        fallback_repositories = []
+        fallback_repository = []
     elif isinstance(fallback_repository, list):
-        fallback_repositories = fallback_repository
+        pass
     else:
-        fallback_repositories = [fallback_repository]
+        fallback_repository = [fallback_repository]
 
-    attempts = [
+    attempts: list[tuple[FileRepository | RepositoryId, dict]] = [
         (repository, save_kwargs),
-        *((fallback, fallback_save_kwargs) for fallback in fallback_repositories),
+        *((fallback, fallback_save_kwargs) for fallback in fallback_repository),
     ]
     for idx, (repo, kwargs) in enumerate(attempts):
         repo_obj = get_builtin_repository(repo)
@@ -201,9 +201,12 @@ class File(BaseModel):
 
         fdata = FileData(data, content_type, file_name)
 
-        object_lifecycle_preference = (
-            request_lifecycle_preference(request) or LIFECYCLE_PREFERENCE.get()
-        )
+        if request:
+            object_lifecycle_preference = request_lifecycle_preference(request)
+        else:
+            print("[WARNING] No request provided, using global lifecycle preference")
+            object_lifecycle_preference = LIFECYCLE_PREFERENCE.get()
+
         save_kwargs.setdefault(
             "object_lifecycle_preference", object_lifecycle_preference
         )
@@ -250,9 +253,13 @@ class File(BaseModel):
         fallback_save_kwargs = fallback_save_kwargs or {}
 
         content_type = content_type or "application/octet-stream"
-        object_lifecycle_preference = (
-            request_lifecycle_preference(request) or LIFECYCLE_PREFERENCE.get()
-        )
+
+        if request:
+            object_lifecycle_preference = request_lifecycle_preference(request)
+        else:
+            print("[WARNING] No request provided, using global lifecycle preference")
+            object_lifecycle_preference = LIFECYCLE_PREFERENCE.get()
+
         save_kwargs.setdefault(
             "object_lifecycle_preference", object_lifecycle_preference
         )
@@ -332,12 +339,9 @@ class CompressedFile(File):
             shutil.rmtree(self.extract_dir)
 
 
-def request_lifecycle_preference(request: Optional[Request]) -> dict[str, str] | None:
+def request_lifecycle_preference(request: Request) -> dict[str, str] | None:
     import json
 
-    if request is None:
-        return None
-
     preference_str = request.headers.get(OBJECT_LIFECYCLE_PREFERENCE_KEY)
     if preference_str is None:
         return None
